==> opencl-clhpp-2.0.13-1-any.pkg.tar.zst: usr/share/doc/opencl-clhpp/namespacecl.js <==
var namespacecl =
[
    [ "compatibility", null, [
      [ "make_kernel", "structcl_1_1compatibility_1_1make__kernel.html", "structcl_1_1compatibility_1_1make__kernel" ]
    ] ],
    [ "detail", null, [
      [ "Deleter", "classcl_1_1detail_1_1_deleter.html", "classcl_1_1detail_1_1_deleter" ],
      [ "GetInfoFunctor0", "structcl_1_1detail_1_1_get_info_functor0.html", "structcl_1_1detail_1_1_get_info_functor0" ],
      [ "GetInfoFunctor1", "structcl_1_1detail_1_1_get_info_functor1.html", "structcl_1_1detail_1_1_get_info_functor1" ],
      [ "KernelArgumentHandler", "structcl_1_1detail_1_1_kernel_argument_handler.html", null ],
      [ "KernelArgumentHandler< cl::DeviceCommandQueue, void >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01cl_1_1_device_command_queue_00_01void_01_4.html", null ],
      [ "KernelArgumentHandler< LocalSpaceArg, void >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_local_space_arg_00_01void_01_4.html", null ],
      [ "KernelArgumentHandler< T, typename std::enable_if< std::is_base_of< cl::Memory, T >::value >::type >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_01std_cb5bfaca8096193f715a7bbe8a3fa84f.html", null ],
      [ "KernelArgumentHandler< T, typename std::enable_if<!std::is_base_of< cl::Memory, T >::value >::type >", "structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_9std_10affa824618af864313998f2e6bcf08f.html", null ],
      [ "param_traits", "structcl_1_1detail_1_1param__traits.html", null ],
      [ "ReferenceHandler", "structcl_1_1detail_1_1_reference_handler.html", null ],
      [ "ReferenceHandler< cl_command_queue >", "structcl_1_1detail_1_1_reference_handler_3_01cl__command__queue_01_4.html", null ],
      [ "ReferenceHandler< cl_context >", "structcl_1_1detail_1_1_reference_handler_3_01cl__context_01_4.html", null ],
      [ "ReferenceHandler< cl_device_id >", "structcl_1_1detail_1_1_reference_handler_3_01cl__device__id_01_4.html", null ],
      [ "ReferenceHandler< cl_event >", "structcl_1_1detail_1_1_reference_handler_3_01cl__event_01_4.html", null ],
      [ "ReferenceHandler< cl_kernel >", "structcl_1_1detail_1_1_reference_handler_3_01cl__kernel_01_4.html", null ],
      [ "ReferenceHandler< cl_mem >", "structcl_1_1detail_1_1_reference_handler_3_01cl__mem_01_4.html", null ],
      [ "ReferenceHandler< cl_platform_id >", "structcl_1_1detail_1_1_reference_handler_3_01cl__platform__id_01_4.html", null ],
      [ "ReferenceHandler< cl_program >", "structcl_1_1detail_1_1_reference_handler_3_01cl__program_01_4.html", null ],
      [ "ReferenceHandler< cl_sampler >", "structcl_1_1detail_1_1_reference_handler_3_01cl__sampler_01_4.html", null ],
      [ "SVMTraitNull", "classcl_1_1detail_1_1_s_v_m_trait_null.html", null ],
      [ "Wrapper", "classcl_1_1detail_1_1_wrapper.html", "classcl_1_1detail_1_1_wrapper" ],
      [ "Wrapper< cl_device_id >", "classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html", "classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4" ]
    ] ],
    [ "Buffer", "classcl_1_1_buffer.html", "classcl_1_1_buffer" ],
    [ "BufferGL", "classcl_1_1_buffer_g_l.html", "classcl_1_1_buffer_g_l" ],
    [ "BufferRenderGL", "classcl_1_1_buffer_render_g_l.html", "classcl_1_1_buffer_render_g_l" ],
    [ "CommandQueue", "classcl_1_1_command_queue.html", "classcl_1_1_command_queue" ],
    [ "Context", "classcl_1_1_context.html", "classcl_1_1_context" ],
    [ "Device", "classcl_1_1_device.html", "classcl_1_1_device" ],
    [ "DeviceCommandQueue", "classcl_1_1_device_command_queue.html", "classcl_1_1_device_command_queue" ],
    [ "EnqueueArgs", "classcl_1_1_enqueue_args.html", "classcl_1_1_enqueue_args" ],
    [ "Event", "classcl_1_1_event.html", "classcl_1_1_event" ],
    [ "Image", "classcl_1_1_image.html", "classcl_1_1_image" ],
    [ "Image1D", "classcl_1_1_image1_d.html", "classcl_1_1_image1_d" ],
    [ "Image1DArray", "classcl_1_1_image1_d_array.html", "classcl_1_1_image1_d_array" ],
    [ "Image1DBuffer", "classcl_1_1_image1_d_buffer.html", "classcl_1_1_image1_d_buffer" ],
    [ "Image2D", "classcl_1_1_image2_d.html", "classcl_1_1_image2_d" ],
    [ "Image2DArray", "classcl_1_1_image2_d_array.html", "classcl_1_1_image2_d_array" ],
    [ "Image2DGL", "classcl_1_1_image2_d_g_l.html", "classcl_1_1_image2_d_g_l" ],
    [ "Image3D", "classcl_1_1_image3_d.html", "classcl_1_1_image3_d" ],
    [ "Image3DGL", "classcl_1_1_image3_d_g_l.html", "classcl_1_1_image3_d_g_l" ],
    [ "ImageFormat", "structcl_1_1_image_format.html", "structcl_1_1_image_format" ],
    [ "ImageGL", "classcl_1_1_image_g_l.html", "classcl_1_1_image_g_l" ],
    [ "Kernel", "classcl_1_1_kernel.html", "classcl_1_1_kernel" ],
    [ "KernelFunctor", "classcl_1_1_kernel_functor.html", "classcl_1_1_kernel_functor" ],
    [ "LocalSpaceArg", "structcl_1_1_local_space_arg.html", "structcl_1_1_local_space_arg" ],
    [ "Memory", "classcl_1_1_memory.html", "classcl_1_1_memory" ],
    [ "NDRange", "classcl_1_1_n_d_range.html", "classcl_1_1_n_d_range" ],
    [ "Pipe", "classcl_1_1_pipe.html", "classcl_1_1_pipe" ],
    [ "Platform", "classcl_1_1_platform.html", "classcl_1_1_platform" ],
    [ "Program", "classcl_1_1_program.html", "classcl_1_1_program" ],
    [ "Sampler", "classcl_1_1_sampler.html", "classcl_1_1_sampler" ],
    [ "SVMAllocator", "classcl_1_1_s_v_m_allocator.html", "classcl_1_1_s_v_m_allocator" ],
    [ "SVMAllocator< void, SVMTrait >", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4" ],
    [ "SVMTraitAtomic", "classcl_1_1_s_v_m_trait_atomic.html", null ],
    [ "SVMTraitCoarse", "classcl_1_1_s_v_m_trait_coarse.html", null ],
    [ "SVMTraitFine", "classcl_1_1_s_v_m_trait_fine.html", null ],
    [ "SVMTraitReadOnly", "classcl_1_1_s_v_m_trait_read_only.html", null ],
    [ "SVMTraitReadWrite", "classcl_1_1_s_v_m_trait_read_write.html", null ],
    [ "SVMTraitWriteOnly", "classcl_1_1_s_v_m_trait_write_only.html", null ],
    [ "UserEvent", "classcl_1_1_user_event.html", "classcl_1_1_user_event" ]
];

==> opencl-clhpp-2024.10.24-1-any.pkg.tar.zst: usr/share/doc/opencl-clhpp/namespacecl.js <==
var namespacecl =
[
    [ "Buffer", "classcl_1_1_buffer.html", "classcl_1_1_buffer" ],
    [ "BufferGL", "classcl_1_1_buffer_g_l.html", "classcl_1_1_buffer_g_l" ],
    [ "BufferRenderGL", "classcl_1_1_buffer_render_g_l.html", "classcl_1_1_buffer_render_g_l" ],
    [ "CommandQueue", "classcl_1_1_command_queue.html", "classcl_1_1_command_queue" ],
    [ "Context", "classcl_1_1_context.html", "classcl_1_1_context" ],
    [ "Device", "classcl_1_1_device.html", "classcl_1_1_device" ],
    [ "DeviceCommandQueue", "classcl_1_1_device_command_queue.html", "classcl_1_1_device_command_queue" ],
    [ "EnqueueArgs", "classcl_1_1_enqueue_args.html", null ],
    [ "Event", "classcl_1_1_event.html", "classcl_1_1_event" ],
    [ "Image", "classcl_1_1_image.html", "classcl_1_1_image" ],
    [ "Image1D", "classcl_1_1_image1_d.html", "classcl_1_1_image1_d" ],
    [ "Image1DArray", "classcl_1_1_image1_d_array.html", "classcl_1_1_image1_d_array" ],
    [ "Image1DBuffer", "classcl_1_1_image1_d_buffer.html", "classcl_1_1_image1_d_buffer" ],
    [ "Image2D", "classcl_1_1_image2_d.html", "classcl_1_1_image2_d" ],
    [ "Image2DArray", "classcl_1_1_image2_d_array.html", "classcl_1_1_image2_d_array" ],
    [ "Image2DGL", "classcl_1_1_image2_d_g_l.html", "classcl_1_1_image2_d_g_l" ],
    [ "Image3D", "classcl_1_1_image3_d.html", "classcl_1_1_image3_d" ],
    [ "Image3DGL", "classcl_1_1_image3_d_g_l.html", "classcl_1_1_image3_d_g_l" ],
    [ "ImageFormat", "structcl_1_1_image_format.html", "structcl_1_1_image_format" ],
    [ "ImageGL", "classcl_1_1_image_g_l.html", "classcl_1_1_image_g_l" ],
    [ "Kernel", "classcl_1_1_kernel.html", "classcl_1_1_kernel" ],
    [ "KernelFunctor", "classcl_1_1_kernel_functor.html", "classcl_1_1_kernel_functor" ],
    [ "LocalSpaceArg", "structcl_1_1_local_space_arg.html", null ],
    [ "Memory", "classcl_1_1_memory.html", "classcl_1_1_memory" ],
    [ "NDRange", "classcl_1_1_n_d_range.html", "classcl_1_1_n_d_range" ],
    [ "Pipe", "classcl_1_1_pipe.html", "classcl_1_1_pipe" ],
    [ "Platform", "classcl_1_1_platform.html", "classcl_1_1_platform" ],
    [ "Program", "classcl_1_1_program.html", "classcl_1_1_program" ],
    [ "Sampler", "classcl_1_1_sampler.html", "classcl_1_1_sampler" ],
    [ "SVMAllocator", "classcl_1_1_s_v_m_allocator.html", "classcl_1_1_s_v_m_allocator" ],
    [ "SVMAllocator< void, SVMTrait >", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html", "classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4" ],
    [ "SVMTraitAtomic", "classcl_1_1_s_v_m_trait_atomic.html", null ],
    [ "SVMTraitCoarse", "classcl_1_1_s_v_m_trait_coarse.html", null ],
    [ "SVMTraitFine", "classcl_1_1_s_v_m_trait_fine.html", null ],
    [ "SVMTraitReadOnly", "classcl_1_1_s_v_m_trait_read_only.html", null ],
    [ "SVMTraitReadWrite", "classcl_1_1_s_v_m_trait_read_write.html", null ],
    [ "SVMTraitWriteOnly", "classcl_1_1_s_v_m_trait_write_only.html", null ],
    [ "UserEvent", "classcl_1_1_user_event.html", "classcl_1_1_user_event" ],
    [ "atomic_svm_vector", "namespacecl.html#a445d7d2f4c3234dc5fbd2d254eb39e22", null ],
    [ "coarse_svm_vector", "namespacecl.html#a2903d8ce897eef7efca4ab6f32f2a197", null ],
    [ "fine_svm_vector", "namespacecl.html#a43fd451f30944f957126b167b4eb0664", null ],
    [ "allocate_pointer", "namespacecl.html#a8e1fce10cd1b8118f51aa91ce0a589e5", null ],
    [ "copy", "namespacecl.html#a05791e9d5da23b21abd6e319fb262c9f", null ],
    [ "copy", "namespacecl.html#a02c4368c6ce7a1a99132eafd5dc96fa9", null ],
    [ "copy", "namespacecl.html#a2f71ed9a316daf59c03c0f3ba62f1bd3", null ],
    [ "copy", "namespacecl.html#a1197a833cdd6664f206b079f2bebd2eb", null ],
    [ "enqueueMapSVM", "namespacecl.html#a640c02cb285c5ab57ab8669bc2146643", null ],
    [ "enqueueMapSVM", "namespacecl.html#a85686c89497c3ef296e3cf1840d7d725", null ],
    [ "enqueueMapSVM", "namespacecl.html#ae48b9857ac37b027d8e946f0cf3c3232", null ],
    [ "enqueueUnmapSVM", "namespacecl.html#a9835d1b49011a71e71b602c8b4db261e", null ],
    [ "enqueueUnmapSVM", "namespacecl.html#ab2784dad151e0aed0685067d190dc994", null ],
    [ "enqueueUnmapSVM", "namespacecl.html#ab76105928c721c5a922a4c1aea804e87", null ],
    [ "Local", "namespacecl.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0", null ],
    [ "mapSVM", "namespacecl.html#ae97dc5bb86e2c3c3935280a86cda301c", null ],
    [ "UnloadCompiler", "namespacecl.html#a2fc824c118740089633cc15e7107f3f0", null ],
    [ "unmapSVM", "namespacecl.html#af9f49b386b20c55c04a9e6cd21849fd5", null ]
];
